@@ -6,7 +6,7 @@ import os
 __version__ = "1.0.0"
 __author__ = "Xcodz"
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     cli = bcli.new_cli()
 
     parser = argparse.ArgumentParser()
@@ -19,28 +19,59 @@ if __name__ == '__main__':
     dir_lister = commands.add_parser("list", description="List a directory")
 
     get.add_argument("-f", "--file", help="Path to file to get", required=True)
-    get.add_argument("-i", "--ip-address", help="IP Address of server", default="127.0.0.1")
+    get.add_argument(
+        "-i", "--ip-address", help="IP Address of server", default="127.0.0.1"
+    )
     get.add_argument("-p", "--port", help="Port to the server", required=True, type=int)
-    get.add_argument("-s", "--store", help="File to store, defaults to file's base name", default=None)
+    get.add_argument(
+        "-s",
+        "--store",
+        help="File to store, defaults to file's base name",
+        default=None,
+    )
 
     post.add_argument("-f", "--file", help="File to post", required=True)
-    post.add_argument("-i", "--ip-address", help="IP Address of server", default="127.0.0.1")
-    post.add_argument("-p", "--port", help="Port to the server", required=True, type=int)
-    post.add_argument("-s", "--store", help="Path for the file to be stored on server, defaults to file's basename",
-                      default=None)
+    post.add_argument(
+        "-i", "--ip-address", help="IP Address of server", default="127.0.0.1"
+    )
+    post.add_argument(
+        "-p", "--port", help="Port to the server", required=True, type=int
+    )
+    post.add_argument(
+        "-s",
+        "--store",
+        help="Path for the file to be stored on server, defaults to file's basename",
+        default=None,
+    )
 
     new.add_argument("-d", "--directory", help="Directory Name", required=True)
-    new.add_argument("-i", "--ip-address", help="IP Address of server", default="127.0.0.1")
+    new.add_argument(
+        "-i", "--ip-address", help="IP Address of server", default="127.0.0.1"
+    )
     new.add_argument("-p", "--port", help="Port to the server", required=True, type=int)
 
-    dir_lister.add_argument("-i", "--ip-address", help="IP Address of server", default="127.0.0.1")
-    dir_lister.add_argument("-p", "--port", help="Port to the server", required=True, type=int)
-    dir_lister.add_argument("-d", "--directory", help="Directory to list", required=True)
+    dir_lister.add_argument(
+        "-i", "--ip-address", help="IP Address of server", default="127.0.0.1"
+    )
+    dir_lister.add_argument(
+        "-p", "--port", help="Port to the server", required=True, type=int
+    )
+    dir_lister.add_argument(
+        "-d", "--directory", help="Directory to list", required=True
+    )
 
-    host.add_argument("-i", "--ip-address", help="IP Address of server", default="127.0.0.1")
-    host.add_argument("-p", "--port", help="Port to the server", required=True, type=int)
-    host.add_argument("-e", "--post-directory", help="Allow the post of users to be limited to this directory",
-                      default=None)
+    host.add_argument(
+        "-i", "--ip-address", help="IP Address of server", default="127.0.0.1"
+    )
+    host.add_argument(
+        "-p", "--port", help="Port to the server", required=True, type=int
+    )
+    host.add_argument(
+        "-e",
+        "--post-directory",
+        help="Allow the post of users to be limited to this directory",
+        default=None,
+    )
     host.add_argument("-d", "--directory", help="Host Directory", default=".")
 
     parser.add_argument("-v", "--version", action="version")
@@ -51,12 +82,14 @@ if __name__ == '__main__':
     args = parser.parse_args()
 
     try:
-        if args.command == 'host':
+        if args.command == "host":
             if not args.no_log:
                 cli.info("Hosting Process Started")
                 cli.info("IP Address :", args.ip_address)
                 cli.info("Port       :", args.port)
-            bdtpfserv.host(args.directory, (args.ip_address, args.port), args.post_directory)
+            bdtpfserv.host(
+                args.directory, (args.ip_address, args.port), args.post_directory
+            )
         elif args.command == "get":
             if not args.no_log:
                 cli.info("Getting file", args.file)
@@ -67,7 +100,7 @@ if __name__ == '__main__':
             file_to_write = args.store
             if file_to_write is None:
                 file_to_write = os.path.basename(args.file)
-            with open(file_to_write, 'w+b') as file:
+            with open(file_to_write, "w+b") as file:
                 file.write(data)
             if not args.no_log:
                 cli.good("File Written")
@@ -92,8 +125,10 @@ if __name__ == '__main__':
             if not args.no_log:
                 cli.good("Directory Made")
         elif args.command == "list":
-            directory_list = bdtpfserv.listdir(args.directory, (args.ip_address, args.port))
-            cli.info("Directory listing of \"", args.directory, '":', sep="")
+            directory_list = bdtpfserv.listdir(
+                args.directory, (args.ip_address, args.port)
+            )
+            cli.info('Directory listing of "', args.directory, '":', sep="")
             for x in directory_list:
                 cli.info("\t", x)
     except KeyboardInterrupt:
